==> openshift-model-config-6.6.2-sources.jar: io/fabric8/openshift/api/model/config/v1/FeatureGateFluent.java <==
package io.fabric8.openshift.api.model.config.v1;

import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import io.fabric8.kubernetes.api.model.ObjectMetaFluent;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface FeatureGateFluent<A extends FeatureGateFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectMeta getMetadata();
  public ObjectMeta buildMetadata();
  public A withMetadata(ObjectMeta metadata);
  public Boolean hasMetadata();
  public FeatureGateFluent.MetadataNested<A> withNewMetadata();
  public FeatureGateFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item);
  public FeatureGateFluent.MetadataNested<A> editMetadata();
  public FeatureGateFluent.MetadataNested<A> editOrNewMetadata();
  public FeatureGateFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item);
  
  /**
   * This method has been deprecated, please use method buildSpec instead.
   * @return The buildable object.
   */
  @Deprecated
  public FeatureGateSpec getSpec();
  public FeatureGateSpec buildSpec();
  public A withSpec(FeatureGateSpec spec);
  public Boolean hasSpec();
  public FeatureGateFluent.SpecNested<A> withNewSpec();
  public FeatureGateFluent.SpecNested<A> withNewSpecLike(FeatureGateSpec item);
  public FeatureGateFluent.SpecNested<A> editSpec();
  public FeatureGateFluent.SpecNested<A> editOrNewSpec();
  public FeatureGateFluent.SpecNested<A> editOrNewSpecLike(FeatureGateSpec item);
  
  /**
   * This method has been deprecated, please use method buildStatus instead.
   * @return The buildable object.
   */
  @Deprecated
  public FeatureGateStatus getStatus();
  public FeatureGateStatus buildStatus();
  public A withStatus(FeatureGateStatus status);
  public Boolean hasStatus();
  public FeatureGateFluent.StatusNested<A> withNewStatus();
  public FeatureGateFluent.StatusNested<A> withNewStatusLike(FeatureGateStatus item);
  public FeatureGateFluent.StatusNested<A> editStatus();
  public FeatureGateFluent.StatusNested<A> editOrNewStatus();
  public FeatureGateFluent.StatusNested<A> editOrNewStatusLike(FeatureGateStatus item);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface MetadataNested<N> extends Nested<N>,ObjectMetaFluent<FeatureGateFluent.MetadataNested<N>>{
    public N and();
    public N endMetadata();
    
  }
  public interface SpecNested<N> extends Nested<N>,FeatureGateSpecFluent<FeatureGateFluent.SpecNested<N>>{
    public N and();
    public N endSpec();
    
  }
  public interface StatusNested<N> extends Nested<N>,FeatureGateStatusFluent<FeatureGateFluent.StatusNested<N>>{
    public N and();
    public N endStatus();
    
  }
  
}

==> openshift-model-config-6.7.0-sources.jar: io/fabric8/openshift/api/model/config/v1/FeatureGateFluent.java <==
package io.fabric8.openshift.api.model.config.v1;

import io.fabric8.kubernetes.api.model.ObjectMeta;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import io.fabric8.kubernetes.api.model.ObjectMetaFluent;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface FeatureGateFluent<A extends FeatureGateFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectMeta getMetadata();
  public ObjectMeta buildMetadata();
  public A withMetadata(ObjectMeta metadata);
  public Boolean hasMetadata();
  public FeatureGateFluent.MetadataNested<A> withNewMetadata();
  public FeatureGateFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item);
  public FeatureGateFluent.MetadataNested<A> editMetadata();
  public FeatureGateFluent.MetadataNested<A> editOrNewMetadata();
  public FeatureGateFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item);
  
  /**
   * This method has been deprecated, please use method buildSpec instead.
   * @return The buildable object.
   */
  @Deprecated
  public FeatureGateSpec getSpec();
  public FeatureGateSpec buildSpec();
  public A withSpec(FeatureGateSpec spec);
  public Boolean hasSpec();
  public FeatureGateFluent.SpecNested<A> withNewSpec();
  public FeatureGateFluent.SpecNested<A> withNewSpecLike(FeatureGateSpec item);
  public FeatureGateFluent.SpecNested<A> editSpec();
  public FeatureGateFluent.SpecNested<A> editOrNewSpec();
  public FeatureGateFluent.SpecNested<A> editOrNewSpecLike(FeatureGateSpec item);
  
  /**
   * This method has been deprecated, please use method buildStatus instead.
   * @return The buildable object.
   */
  @Deprecated
  public FeatureGateStatus getStatus();
  public FeatureGateStatus buildStatus();
  public A withStatus(FeatureGateStatus status);
  public Boolean hasStatus();
  public FeatureGateFluent.StatusNested<A> withNewStatus();
  public FeatureGateFluent.StatusNested<A> withNewStatusLike(FeatureGateStatus item);
  public FeatureGateFluent.StatusNested<A> editStatus();
  public FeatureGateFluent.StatusNested<A> editOrNewStatus();
  public FeatureGateFluent.StatusNested<A> editOrNewStatusLike(FeatureGateStatus item);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface MetadataNested<N> extends Nested<N>,ObjectMetaFluent<FeatureGateFluent.MetadataNested<N>>{
    public N and();
    public N endMetadata();
    
  }
  public interface SpecNested<N> extends Nested<N>,FeatureGateSpecFluent<FeatureGateFluent.SpecNested<N>>{
    public N and();
    public N endSpec();
    
  }
  public interface StatusNested<N> extends Nested<N>,FeatureGateStatusFluent<FeatureGateFluent.StatusNested<N>>{
    public N and();
    public N endStatus();
    
  }
  
}
